; GIMP - The GNU Image Manipulation Program
; Copyright (C) 1995 Spencer Kimball and Peter Mattis
;
; This program is free software; you can redistribute it and/or modify
; it under the terms of the GNU General Public License as published by
; the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.
;
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
;
; You should have received a copy of the GNU General Public License
; along with this program.  If not, see <http://www.gnu.org/licenses/>.
;
; Image Info - a script-fu for GIMP
;
; Image Info creates a new layer containing
; informations (title, path, size, resolution..) for the current image
;
; Copyright (C) 2008 Radu Feflea <radu.feflea@gmail.com>
;
; v0.1	- 02.12.08
;		- the very first version
; v0.2	- 08.12.08
;		- added a custom title field
;		- some minor improvements
;
; TODO
;		- switch to include the text in the picture and not on a new layer (automatic layer merging)
;		- batch-mode for multiple file editing
;

(define (script-fu-image-info image
							textColor
							backColor
							textFont
							dispCustom
							customText
							dispPath
							dispSize
							dispRes)

	(let*
		(
			(contextFore 0)
			(contextBack 0)
			(imageWidth 0)
			(imageHeight 0)
			(imageFilename 0)
			(imageResX 0)
			(imageResY 0)
			(footerLayer 0)
			(footerLayerHeight 0)
			(textLayer 0)
			(textLayerWidth 0)
			(text 0)
			(textSize 0)
			(textRow 0)
			(textRows 2)
			
			(infoScale 14)
		)
		
		(gimp-image-undo-group-start image)
		
		; init variables
						
		(set! contextFore (car (gimp-context-get-foreground)))
		(set! contextBack (car (gimp-context-get-background)))
		(set! imageWidth (car (gimp-image-width image)))
		(set! imageHeight (car (gimp-image-height image)))
		(set! imageFilename (car (gimp-image-get-filename image)))
		(set! imageResX (car (gimp-image-get-resolution image)))
		(set! imageResY (cadr (gimp-image-get-resolution image)))
		
		(set! footerLayerHeight (/ imageHeight infoScale))
		
		(set! textSize (/ footerLayerHeight 3))
		
		; resizing the image
		
		(gimp-image-resize image imageWidth (+ imageHeight footerLayerHeight) 0 0)
		
		; creating the footerLayer
		
	    (set! footerLayer (car (gimp-layer-new image
											imageWidth
											footerLayerHeight
											RGB-IMAGE
											"image_info"
											100
											NORMAL-MODE)))
												
		(gimp-image-add-layer image footerLayer 200)
		(gimp-layer-set-offsets footerLayer 0 imageHeight)
		
		; setting the new colors
		
		(gimp-context-set-foreground textColor)
		(gimp-context-set-background backColor)
		
		(gimp-drawable-fill footerLayer BACKGROUND-FILL)		
		
		; writting the cutom title

		(if (= dispCustom 1)
			(begin
				(set! textLayer (car (gimp-text-fontname image
													footerLayer
													3
													(+ imageHeight 2 (* textRow (/ footerLayerHeight 2)))
													customText
													-1
													TRUE
													textSize
													PIXELS
													textFont)))
				
				(gimp-floating-sel-anchor textLayer)
				
				(set! textRow (+ textRow 1))
			)
		)		; writting the filename

		(if (= dispPath 1)
			(begin
				(set! textLayer (car (gimp-text-fontname image
													footerLayer
													3
													(+ imageHeight 2 (* textRow (/ footerLayerHeight 2)))
													imageFilename
													-1
													TRUE
													textSize
													PIXELS
													textFont)))
				
				(gimp-floating-sel-anchor textLayer)
				
				(set! textRow (+ textRow 1))
			)
		)
		
		; going on the second column -> resetting textRow to 0
		
		(set! textRow 0)
		
		; writting the image size
		; right-aligned
		
		(if (= dispSize 1)
			(begin
				(set! textLayer (car (gimp-text-fontname image
												footerLayer
												0
												0
												(string-append (number->string imageWidth) " x " (number->string imageHeight) " px")
												-1
												TRUE
												textSize
												PIXELS
												textFont)))

		; getting the text's width and then aligning it to right

				(set! textLayerWidth (car (gimp-drawable-width textLayer)))

				(gimp-layer-translate textLayer
												(- imageWidth textLayerWidth 3)
												(+ imageHeight 2))
												
				(gimp-floating-sel-anchor textLayer)
				
				(set! textRow (+ textRow 1))
			)
		)

		; writting the resolution
		; on the 2nd row right-aligned

		(if (= dispRes 1)
			(begin
				(set! textLayer (car (gimp-text-fontname image
												footerLayer
												0
												0
												(string-append (number->string imageResX) " x " (number->string imageResY) " dpi")
												-1
												TRUE
												textSize
												PIXELS
												textFont)))
			
		; getting the text's width and then aligning it to right

			(set! textLayerWidth (car (gimp-drawable-width textLayer)))
			
				(gimp-layer-translate textLayer
												(- imageWidth textLayerWidth 3)
												(+ imageHeight 2 (* textRow (/ footerLayerHeight 2))))
			
				(gimp-floating-sel-anchor textLayer)

				(set! textRow (+ textRow 1))
			)
		)
		
		; setting old colors back
		
		(gimp-context-set-foreground contextFore)
		(gimp-context-set-background contextBack)

		; finish
		
		(gimp-image-undo-group-end image)
		(gimp-displays-flush)
	)
)

(script-fu-register "script-fu-image-info"
	_"Add Image Info"
	_"Adds a footer to the current image containing infos about it"
	"Radu Feflea"
	"2008 Radu Feflea. Public Domain"
	"December 2008"
	""
	SF-IMAGE		"Image"					0
    SF-COLOR		"Text color"				'(255 255 255)
    SF-COLOR		"Background color"	'(0 0 0)
    SF-FONT		"Font"					"sans"
	SF-TOGGLE		"Custom title"			TRUE
	SF-STRING		"Text String"			"my custom title"
	SF-TOGGLE		"Image Path"			TRUE
	SF-TOGGLE		"Image Size"			TRUE
	SF-TOGGLE		"Image Resolution"	TRUE
)

(script-fu-menu-register "script-fu-image-info"
	"<Image>/Image")
